pub enum DegreeSequenceMethod {
Configuration,
VigerLatapy,
FastHeurSimple,
ConfigurationSimple,
EdgeSwitchingSimple,
}Expand description
Method for sampling graphs with a given degree sequence (igraph_degseq_t).
Variants
Configuration
Configuration model, may produce loops and multi-edges.
VigerLatapy
Viger–Latapy: undirected simple connected graphs, sampled approximately uniformly (a Monte Carlo method based on degree-preserving edge switches).
FastHeurSimple
Fast heuristic generating simple graphs: like the configuration model, but avoiding loops and multi-edges and restarting when stuck (not uniform).
ConfigurationSimple
Configuration model with rejection of non-simple graphs: uniform simple graphs (possibly slow).
EdgeSwitchingSimple
Edge-switching Markov chain started from a realization of the sequence: simple (directed or undirected) graphs.