pub enum FasAlgorithm {
ExactIp,
ApproxEades,
ExactIpCg,
ExactIpTi,
}Expand description
Feedback arc set algorithm (igraph_fas_algorithm_t).
Variants
ExactIp
Minimum feedback arc set by integer programming, letting igraph
pick the best such method (currently FasAlgorithm::ExactIpCg).
ApproxEades
Eades–Lin–Smyth heuristic: linear time, at most |E|/2 - |V|/6
edges, not necessarily minimum.
ExactIpCg
Exact integer programming on a set cover formulation, with incremental generation of cycle constraints.
ExactIpTi
Exact integer programming on a topological order formulation with
triangle inequalities (typically much slower than
FasAlgorithm::ExactIpCg).