Loops

Enum Loops 

pub enum Loops {
    None,
    Twice,
    Once,
}
How self-loops are counted (igraph_loops_t).

Variants



None

Ignore loop edges.



Twice

Count each loop twice, as it has two endpoints at the same vertex (the graph theoretical convention, which keeps the handshake lemma true).



Once

Count each loop once. Only meaningful when edge directions are ignored: for out- or in-degrees of directed graphs each loop counts once anyway.