pub enum LpaVariant {
Dominance,
Retention,
Fast,
}Expand description
Label propagation variant (igraph_lpa_variant_t).
Variants
Dominance
Sample from the dominant labels, and check the dominance of all vertices after each iteration.
Retention
Keep the current label if it is among the dominant ones; only check the vertices whose labels changed.
Fast
Sample from the dominant labels, only checking neighbors (fast).