pub enum ToDirected {
Arbitrary,
Mutual,
Random,
Acyclic,
}Expand description
How to convert undirected edges to directed ones (igraph_to_directed_t).
Variants
Arbitrary
One directed edge with arbitrary direction.
Mutual
Two mutual directed edges.
Random
One directed edge with random direction.
Acyclic
From lower to higher vertex id, giving an acyclic graph.