pub enum VconnNei {
Error,
NumberOfNodes,
Ignore,
Negative,
}Expand description
What to do when computing the vertex connectivity of two adjacent
vertices, which no vertex removal can disconnect
(igraph_vconn_nei_t).
Variants
Error
Report an error.
NumberOfNodes
Return the number of vertices.
Ignore
Ignore the edges between them: count the vertices needed to cut all the other paths.
Negative
Return -1.